<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'Pastebin.com is the number one paste tool since 2002. Pastebin is a website where you can store text online for a set period of time.',
    'favicon' => 'https://pastebin.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://pastebin.com/i/facebook.png',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Pastebin',
    'providerUrl' => 'https://pastebin.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Pushing new git submodule to Heroku - Pastebin.com',
    'url' => 'https://pastebin.com/d4biUtRm',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
